/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mouse Gestures (Locale Switcher module).
 *
 * The Initial Developer of the Original Code is Jens Bannmann.
 * Portions created by the Initial Developer are Copyright (C) 2004
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s) (alphabetical order):
 *  Jens Bannmann <jens.b@web.de>
 *  Jochen <autohide@krickelkrackel.de>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

const mtChromeRegistry = Components.classes["@mozilla.org/chrome/chrome-registry;1"]
                                 .getService(Components.interfaces.nsIXULChromeRegistry);
var mtLS_JarBasePath = null;
var mtLS_InProfile;

window.addEventListener("load", mtLS_Startup, false);

function mtLS_Startup() {
  // Ensure we *can* change locales
  if ( !("selectLocaleForPackage" in mtChromeRegistry) ) {
    return;
  }

  // Determine base jar path. We cannot use resource:///chrome/moztweaks.jar as it
  // wouldn't work with profile installs. Therefore, ask the chrome registry...
  var oRdf = Components.classes["@mozilla.org/rdf/rdf-service;1"].getService(Components.interfaces.nsIRDFService);

  try {
     var oDs = oRdf.GetDataSourceBlocking("rdf:chrome");
  }
  catch (e) {
     return;
  }
  var oBasePath = oDs.GetTarget(oRdf.GetResource("urn:mozilla:package:moztweaks"),
                                oRdf.GetResource("http://www.mozilla.org/rdf/chrome#baseURL"),
                                true);
  if(oBasePath instanceof Components.interfaces.nsIRDFLiteral){
    mtLS_JarBasePath = oBasePath.Value;
    mtLS_JarBasePath = mtLS_JarBasePath.substring(0, mtLS_JarBasePath.lastIndexOf("!") + 1);
    setTimeout(mtLS_CheckLocale, 1000); // seems to be neccessary to avoid startup freeze
  } else {
    dump("moztweaks: Could not determine jar base path - skipping locale check.\n");
  }

  // Determine whether moztweaks is installed into the user profile
  // (needed for locale registration)
  mtLS_InProfile = true;
  var inProfile = oDs.GetTarget(oRdf.GetResource("urn:mozilla:package:moztweaks"),
                                oRdf.GetResource("http://www.mozilla.org/rdf/chrome#locType"),
                                true);
  if (inProfile instanceof Components.interfaces.nsIRDFLiteral
      && inProfile.Value == "install") {
    mtLS_InProfile = false;
  }
}

function mtLS_CheckLocale() {
  const promptService = Components.classes["@mozilla.org/embedcomp/prompt-service;1"]
                        .getService(Components.interfaces.nsIPromptService);
  var properties = mtLS_GetBundle("chrome://moztweaks/content/mtbuild.properties");

  // Determine package locales
  var moztweaksLocale = mtChromeRegistry.getSelectedLocale("moztweaks");
  var defaultLocale = properties.GetStringFromName("moztweaks.defaultLocale");
  var appLocale = mtChromeRegistry.getSelectedLocale("global");

  var supportedLocales = properties.GetStringFromName("moztweaks.supportedLocales");
  var appLocaleSupported = (","+supportedLocales+",").indexOf( (","+appLocale+",") ) > -1;

  var switchTo = null;

  // Revert to default (or app locale) if moztweaksLocale is not supported
  if ( (","+supportedLocales+",").indexOf( (","+moztweaksLocale+",") ) == -1) {
    switchTo = appLocaleSupported ? appLocale : defaultLocale;
  }
  // Is moztweaks not on the app locale, but supports it?
  else if (moztweaksLocale != appLocale && appLocaleSupported) {
    switchTo = appLocale;
  }

  if (switchTo != null) {
    if (switchTo != defaultLocale) {
      mtChromeRegistry.installLocale(mtLS_JarBasePath+"/locale/"+switchTo+"/moztweaks/", mtLS_InProfile);
    }
    mtChromeRegistry.selectLocaleForPackage(switchTo, "moztweaks", true);
    promptService.alert(window,
                        "Optimoz Tweaks",
                        "Optimoz Tweaks changed its language settings. Please restart Mozilla.");
  }
}

function mtLS_GetBundle(url) {
  return Components.classes["@mozilla.org/intl/stringbundle;1"].getService()
                   .QueryInterface(Components.interfaces.nsIStringBundleService)
                   .createBundle(url);
}