/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Optimoz Tweaks.
 *
 * The Initial Developer of the Original Code is Jens Bannmann.
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s) (alphabetical order):
 *  Jens Bannmann <jens.b@web.de>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var mtPrefSearchbarAutoExpand;
var mtPrefSearchbarExpandStep;
var mtPrefSearchbarExpandTime;
var mtSearchbar;
var mtSearchbarSmall;
var mtSearchbarBig;
var mtSearchbarFocused;
var mtSearchbarInterval = 0;
var mtSearchbarResizeTask = null;

function mtInitSearchbar() {
  mtPrefSearchbarAutoExpand = mtGetPref("searchbar.autoExpand", "Bool", false);
  mtPrefSearchbarExpandStep = mtGetPref("searchbar.expandStep", "Int", 10, 1, 50);
  mtPrefSearchbarExpandTime = mtGetPref("searchbar.expandTime", "Int", 250, 0, 1000);
  var expandToPercent = mtGetPref("searchbar.expandToPercent", "Int", 200, 100, 500);
  mtSearchbar = document.getElementById("searchbar");
  if (mtSearchbar) {
    mtSearchbar.addEventListener("focus", mtSearchbarFocusHandler, true);
    mtSearchbar.addEventListener("blur", mtSearchbarFocusHandler, true);

    mtSearchbarSmall = mtSearchbar.boxObject.width;
    mtSearchbarBig = Math.round(mtSearchbarSmall * (expandToPercent / 100));
    mtSearchbarInterval = Math.round(mtPrefSearchbarExpandTime / ((mtSearchbarBig-mtSearchbarSmall) / mtPrefSearchbarExpandStep));
    mtSearchbarFocused = false;
  }
}

function mtSearchbarFocusHandler(e) {
  if (mtPrefSearchbarAutoExpand) {
    if (e.type=="focus") {
      mtSearchbarFocused = true;
      dump("mtSearchbarFocused = true\n");
    } else {
      mtSearchbarFocused = false;
      dump("mtSearchbarFocused = false\n");
    }
    if (mtPrefSearchbarExpandTime == 0) {
      mtSearchbar.setAttribute("width", mtSearchbarFocused ? mtSearchbarBig : mtSearchbarSmall);
    } else if (mtSearchbarResizeTask == null) {
      mtSearchbarResizeTask = window.setInterval(mtSearchbarResizer, mtSearchbarInterval);
      dump("task started\n");
    }
  }
}

function mtSearchbarResizer() {
  var w = mtSearchbar.boxObject.width;
  if (mtSearchbarFocused) {
    if (w >= mtSearchbarBig) {
      window.clearInterval(mtSearchbarResizeTask);
      mtSearchbarResizeTask = null;
      dump("task ended ("+w+")\n");
      return;
    }
    w = w + mtPrefSearchbarExpandStep;
  } else {
    if (w <= mtSearchbarSmall) {
      window.clearInterval(mtSearchbarResizeTask);
      mtSearchbarResizeTask = null;
      dump("task ended ("+w+")\n");
      return;
    }
    w = w - mtPrefSearchbarExpandStep;
  }
  mtSearchbar.setAttribute("width", w);
}
